@@ -23,17 +23,17 @@
 #include "ev-document-layers.h"
 #include "ev-document.h"
 
-EV_DEFINE_INTERFACE (EvDocumentLayers, ev_document_layers, 0)
+G_DEFINE_INTERFACE (EvDocumentLayers, ev_document_layers, 0)
 
 static void
-ev_document_layers_class_init (EvDocumentLayersIface *klass)
+ev_document_layers_default_init (EvDocumentLayersInterface *klass)
 {
 }
 
 gboolean
 ev_document_layers_has_layers (EvDocumentLayers *document_layers)
 {
-	EvDocumentLayersIface *iface = EV_DOCUMENT_LAYERS_GET_IFACE (document_layers);
+	EvDocumentLayersInterface *iface = EV_DOCUMENT_LAYERS_GET_IFACE (document_layers);
 
 	return iface->has_layers (document_layers);
 }
@@ -41,7 +41,7 @@ ev_document_layers_has_layers (EvDocumentLayers *document_layers)
 GtkTreeModel *
 ev_document_layers_get_layers (EvDocumentLayers *document_layers)
 {
-	EvDocumentLayersIface *iface = EV_DOCUMENT_LAYERS_GET_IFACE (document_layers);
+	EvDocumentLayersInterface *iface = EV_DOCUMENT_LAYERS_GET_IFACE (document_layers);
 
 	return iface->get_layers (document_layers);
 }
@@ -50,7 +50,7 @@ void
 ev_document_layers_show_layer (EvDocumentLayers *document_layers,
 			       EvLayer          *layer)
 {
-	EvDocumentLayersIface *iface = EV_DOCUMENT_LAYERS_GET_IFACE (document_layers);
+	EvDocumentLayersInterface *iface = EV_DOCUMENT_LAYERS_GET_IFACE (document_layers);
 
 	iface->show_layer (document_layers, layer);
 }
@@ -59,7 +59,7 @@ void
 ev_document_layers_hide_layer (EvDocumentLayers *document_layers,
 			       EvLayer          *layer)
 {
-	EvDocumentLayersIface *iface = EV_DOCUMENT_LAYERS_GET_IFACE (document_layers);
+	EvDocumentLayersInterface *iface = EV_DOCUMENT_LAYERS_GET_IFACE (document_layers);
 
 	iface->hide_layer (document_layers, layer);
 }
@@ -68,7 +68,7 @@ gboolean
 ev_document_layers_layer_is_visible (EvDocumentLayers *document_layers,
 				     EvLayer          *layer)
 {
-	EvDocumentLayersIface *iface = EV_DOCUMENT_LAYERS_GET_IFACE (document_layers);
+	EvDocumentLayersInterface *iface = EV_DOCUMENT_LAYERS_GET_IFACE (document_layers);
 
 	return iface->layer_is_visible (document_layers, layer);
 }
